summaryrefslogtreecommitdiffstats
path: root/cervisia/entry.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
commit3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b (patch)
tree4405f233f4b0eee7f4ad3d265a5584c9ce681011 /cervisia/entry.h
parentd6331f1b56eb6dca7a1950658b2932f208015da0 (diff)
downloadtdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.tar.gz
tdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit d6331f1b56eb6dca7a1950658b2932f208015da0.
Diffstat (limited to 'cervisia/entry.h')
-rw-r--r--cervisia/entry.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cervisia/entry.h b/cervisia/entry.h
index f3705d35..2c0a1c98 100644
--- a/cervisia/entry.h
+++ b/cervisia/entry.h
@@ -43,7 +43,7 @@ struct Entry
};
/**
* Sets status to \a EntryStatus::Unknown and type to \a File.
*/
Entry();
@@ -60,7 +60,7 @@ struct Entry
/**
* The status of this entry.
*/
- EntryStatus m_status;
+ EntrytqStatus m_status;
/**
* The revision of this entry.
@@ -43,7 +43,7 @@ struct Entry
};
/**
- * Sets status to \a EntryStatus::Unknown and type to \a File.
+ * Sets status to \a EntrytqStatus::Unknown and type to \a File.
*/
Entry();